/* ISC license. */

/* Generated by: ./configure --prefix=/usr --sysconfdir=/etc --libexecdir=/usr/lib --conffile=/etc/s6-frontend.conf --disable-allstatic --disable-static --enable-pkgconfig --enable-shared --enable-util-linux --with-pkgconfig */

#ifndef S6_FRONTEND_CONFIG_H
#define S6_FRONTEND_CONFIG_H

#define S6_FRONTEND_VERSION "0.1.0.0"
#define S6_FRONTEND_BINPREFIX ""
#define S6_FRONTEND_EXTBINPREFIX ""
#define S6_FRONTEND_EXTLIBEXECPREFIX "/usr/lib/"
#define S6_FRONTEND_LIBEXECPREFIX "/usr/lib/"
#define S6_FRONTEND_SYSCONFPREFIX "/etc/"
#undef S6_FRONTEND_USE_UTIL_LINUX
#define S6_FRONTEND_USE_UTIL_LINUX
#undef S6_FRONTEND_USE_S6LI
#define S6_FRONTEND_USE_S6LI
#include <s6-linux-init/config.h>
#undef S6_FRONTEND_SCANDIR
#define S6_FRONTEND_SCANDIR S6_LINUX_INIT_TMPFS "/" S6_LINUX_INIT_SCANDIR
#undef S6_FRONTEND_LIVEDIR
#include <s6-rc/config.h>
#define S6_FRONTEND_LIVEDIR S6RC_LIVEDIR
#undef S6_FRONTEND_REPODIR
#define S6_FRONTEND_REPODIR S6RC_REPODIR
#undef S6_FRONTEND_BOOTDB
#define S6_FRONTEND_BOOTDB S6RC_BOOTDB
#undef S6_FRONTEND_DEFBUNDLE
#define S6_FRONTEND_DEFBUNDLE S6RC_DEFBUNDLE
#undef S6_FRONTEND_STMPDIR
#define S6_FRONTEND_STMPDIR "/run/s6-frontend"
#undef S6_FRONTEND_CONF
#define S6_FRONTEND_CONF "/etc/s6-frontend.conf"
#undef S6_FRONTEND_STORELIST
#define S6_FRONTEND_STORELIST "/usr/share/s6/sources:/etc/s6/sources"
#undef S6_FRONTEND_FDHUSER
#define S6_FRONTEND_FDHUSER ""

#endif
